"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _useMemoOne = require("use-memo-one");

var _reactNative = require("react-native");

var _react = _interopRequireWildcard(require("react"));

var _ModalStack = _interopRequireDefault(require("./ModalStack"));

var _ModalState = _interopRequireDefault(require("./ModalState"));

var _ModalContext = _interopRequireDefault(require("./ModalContext"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * `<ModalProvider>` is the component you're going to use to wrap your whole application,
 * so it'll be able to display your modals on top of everything else, using React Context API.
 *
 * @prop { ModalStackType } `stack` - Modal stack object generated by `createModalStack()`
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/guides/stack#provider
 */
const ModalProvider = _ref => {
  let {
    children,
    stack
  } = _ref;
  const modalStateSubscription = (0, _react.useRef)();
  const modalEventListeners = (0, _react.useRef)(new Set()).current;

  const openModal = (modalName, params, callback) => {
    const {
      currentModal
    } = _ModalState.default.getState();

    if (!currentModal) {
      _reactNative.BackHandler.addEventListener('hardwareBackPress', _ModalState.default.handleBackPress);
    }

    _ModalState.default.openModal({
      modalName,
      params,
      callback,
      isCalledOutsideOfContext: true
    });
  };

  const getParam = (hash, paramName, defaultValue) => _ModalState.default.getParam(hash, paramName, defaultValue);

  const closeModal = stackItem => _ModalState.default.closeModal(stackItem);

  const closeModals = modalName => _ModalState.default.closeModals(modalName);

  const closeAllModals = () => _ModalState.default.closeAllModals();

  const [contextValue, setContextValue] = (0, _react.useState)({
    stack,
    getParam,
    openModal,
    closeModal,
    closeModals,
    closeAllModals,
    currentModal: null
  });
  const registerListener = (0, _useMemoOne.useCallback)((hash, eventName, handler) => {
    (0, _utils.validateListener)('add', {
      eventName,
      handler
    });
    const newListener = {
      event: `${hash}_${eventName}`,
      handler
    };
    modalEventListeners.add(newListener);
    return {
      remove: () => modalEventListeners.delete(newListener)
    };
  }, [modalEventListeners]);
  const clearListeners = (0, _useMemoOne.useCallback)(hash => {
    modalEventListeners.forEach(item => {
      if (item.event.includes(hash)) modalEventListeners.delete(item);
    });
  }, [modalEventListeners]);

  const listener = (modalState, error) => {
    if (modalState) {
      setContextValue({ ...contextValue,
        currentModal: modalState.currentModal,
        stack: modalState.stack
      });
    } else console.warn('Modalfy', error);
  };

  (0, _react.useEffect)(() => {
    (0, _utils.invariant)(stack, 'You need to provide a `stack` prop to <ModalProvider>');

    _ModalState.default.init(() => ({
      currentModal: null,
      stack
    }));

    modalStateSubscription.current = _ModalState.default.subscribe(listener);
    return () => {
      var _modalStateSubscripti;

      _reactNative.BackHandler.removeEventListener('hardwareBackPress', _ModalState.default.handleBackPress);

      (_modalStateSubscripti = modalStateSubscription.current) === null || _modalStateSubscripti === void 0 ? void 0 : _modalStateSubscripti.unsubscribe();
    };
  }, []);
  (0, _react.useEffect)(() => {
    // NOTE: Used to prevent scrolling on Web when the modal stack is opened.
    if (_reactNative.Platform.OS === 'web' && contextValue.stack.openedItems.size) {
      document.body.style.overflow = 'hidden';
      document.body.style.touchAction = 'none';
      document.body.style.overscrollBehavior = 'none';
    }

    return () => {
      if (_reactNative.Platform.OS === 'web') {
        document.body.style.overflow = 'auto';
        document.body.style.touchAction = 'auto';
        document.body.style.overscrollBehavior = 'auto';
      }
    };
  }, [contextValue.stack.openedItems.size]);
  return /*#__PURE__*/_react.default.createElement(_ModalContext.default.Provider, {
    value: contextValue
  }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children, /*#__PURE__*/_react.default.createElement(_ModalStack.default, _extends({}, contextValue, {
    clearListeners: clearListeners,
    registerListener: registerListener,
    eventListeners: modalEventListeners,
    removeClosingAction: _ModalState.default.removeClosingAction
  }))));
};

var _default = ModalProvider;
exports.default = _default;
//# sourceMappingURL=ModalProvider.js.map