"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _useMemoOne = require("use-memo-one");

var _reactNative = require("react-native");

var _StackItem = _interopRequireDefault(require("./StackItem"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const ModalStack = props => {
  const {
    stack
  } = props;
  const [hasChangedBackdropColor, setBackdropColorStatus] = (0, _react.useState)(false);
  const [backdropClosedItems, setBackdropClosedItems] = (0, _react.useState)([]);
  const [openActionCallbacks, setOpenActionCallbacks] = (0, _react.useState)([]);
  const [stackStatus, setStackStatus] = (0, _react.useState)('idle');
  const canShowStack = stackStatus === 'hiding' || stackStatus === 'shown';
  const {
    opacity,
    translateY
  } = (0, _useMemoOne.useMemo)(() => ({
    opacity: new _reactNative.Animated.Value(0),
    translateY: new _reactNative.Animated.Value((0, _utils.sh)(100))
  }), []);
  const {
    backBehavior,
    backdropAnimationDuration,
    backdropColor,
    backdropOpacity
  } = (0, _useMemoOne.useMemo)(() => (0, _utils.getStackItemOptions)(Array.from(stack.openedItems).pop(), stack), [stack]);
  const hideBackdrop = (0, _useMemoOne.useCallback)(() => {
    if (stackStatus === 'shown') {
      setStackStatus('hiding');

      _reactNative.Animated.timing(opacity, {
        toValue: 0,
        easing: _reactNative.Easing.inOut(_reactNative.Easing.ease),
        duration: backdropAnimationDuration,
        useNativeDriver: true
      }).start(() => {
        setStackStatus('hidden');
        setBackdropClosedItems([]);
        translateY.setValue((0, _utils.sh)(100));
      });
    }
  }, [backdropAnimationDuration, opacity, translateY, stackStatus]);
  (0, _react.useEffect)(() => {
    if (stack.openedItems.size && backdropColor && backdropColor !== 'black' && !hasChangedBackdropColor) {
      setBackdropColorStatus(true);
    }
  }, [backdropColor, hasChangedBackdropColor, stack.openedItems.size]);
  (0, _react.useEffect)(() => {
    var _window$scrollY;

    const scrollY = _reactNative.Platform.OS === 'web' ? (_window$scrollY = window.scrollY) !== null && _window$scrollY !== void 0 ? _window$scrollY : document.documentElement.scrollTop : 0;

    if (stack.openedItems.size) {
      setStackStatus('shown');
      translateY.setValue(scrollY);

      _reactNative.Animated.timing(opacity, {
        toValue: 1,
        easing: _reactNative.Easing.in(_reactNative.Easing.ease),
        duration: backdropAnimationDuration,
        useNativeDriver: true
      }).start();
    } else hideBackdrop();
  }, [backdropAnimationDuration, opacity, stack.openedItems.size, translateY]);

  const renderStackItem = (stackItem, index) => {
    const position = stack.openedItems.size - index;
    const isFirstVisibleModal = position === stack.openedItems.size;
    const isLastOpenedModal = position === 1 && stack.openedItems.size === 1;
    const pendingClosingAction = stack.pendingClosingActions.values().next().value;
    const hasPendingClosingAction = position === 1 && (pendingClosingAction === null || pendingClosingAction === void 0 ? void 0 : pendingClosingAction.currentModalHash) === stackItem.hash;
    return /*#__PURE__*/_react.default.createElement(_StackItem.default, _extends({}, props, {
      // @ts-ignore
      stackItem: stackItem,
      key: index,
      zIndex: index + 1,
      position: position,
      hideBackdrop: hideBackdrop,
      openModal: function () {
        // @ts-ignore
        props.openModal(...arguments);
        setOpenActionCallbacks(state => [...state, stackItem.hash]);
      },
      isLastOpenedModal: isLastOpenedModal,
      isFirstVisibleModal: isFirstVisibleModal,
      wasOpenCallbackCalled: openActionCallbacks.includes(stackItem.hash),
      wasClosedByBackdropPress: backdropClosedItems.includes(stackItem.hash),
      pendingClosingAction: hasPendingClosingAction ? pendingClosingAction : undefined
    }));
  };

  const renderStack = () => {
    if (!stack.openedItems.size) return null;
    return [...stack.openedItems].map(renderStackItem);
  };

  const onBackdropPress = () => {
    if (backBehavior === 'none') return;
    const currentItem = [...stack.openedItems].slice(-1)[0];
    setBackdropClosedItems([...backdropClosedItems, currentItem === null || currentItem === void 0 ? void 0 : currentItem.hash]);
  };

  const renderBackdrop = () => {
    const onPress = () => onBackdropPress();

    const backgroundColor = stack.openedItems.size && backdropColor ? backdropColor : hasChangedBackdropColor ? 'transparent' : 'black';
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
      onPress: onPress
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: [styles.backdrop, {
        backgroundColor,
        opacity: opacity.interpolate({
          inputRange: [0, 1],
          outputRange: [0, backdropOpacity !== null && backdropOpacity !== void 0 ? backdropOpacity : _utils.defaultOptions.backdropOpacity]
        })
      }]
    }));
  };

  return canShowStack ? /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.container, {
      opacity,
      transform: [{
        translateY
      }]
    }, _reactNative.Platform.OS === 'web' && stack.openedItems.size ? styles.containerWeb : null]
  }, renderBackdrop(), renderStack()) : null;
};

const styles = _reactNative.StyleSheet.create({
  container: { ..._reactNative.Platform.select({
      android: { ..._reactNative.StyleSheet.absoluteFillObject,
        zIndex: 0
      },
      ios: { ..._reactNative.StyleSheet.absoluteFillObject,
        zIndex: 0
      }
    })
  },
  containerWeb: { ..._reactNative.StyleSheet.absoluteFillObject,
    overflow: 'hidden',
    height: '100vh',
    width: '100vw',
    zIndex: 0,
    // mobile viewport units bug fix
    maxHeight: '-webkit-fill-available',
    maxWidth: '-webkit-fill-available'
  },
  backdrop: { ..._reactNative.StyleSheet.absoluteFillObject
  }
});

var _default = ModalStack;
exports.default = _default;
//# sourceMappingURL=ModalStack.js.map