"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _utils = require("../utils");

/**
 * `createModalStack()` is the function that's going to turn your configuration into a usable modal stack.
 *
 * @argument { ModalStackConfig } config - Modal stack configuration.
 * @argument { ModalOptions } [customDefaultOptions] - Configuration options to apply to all modals by default (optional).
 *
 * @returns { ModalStack } Modal stack configuration object to provide to `<ModalProvider>`'s `stack` prop.
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/guides/stack
 */
function _default(config, customDefaultOptions) {
  (0, _utils.invariant)(config, 'You need to provide a config to createModalStack()');
  (0, _utils.validateDefaultOptions)(customDefaultOptions);
  const initialStack = {
    names: [],
    content: [],
    defaultOptions: { ..._utils.defaultOptions,
      ...customDefaultOptions
    },
    openedItems: new Set(),
    pendingClosingActions: new Set()
  };
  return Object.entries(config).reduce((output, entry, index) => {
    const {
      name,
      component,
      options
    } = (0, _utils.getStackItemData)(entry[0], entry[1]);
    return { ...output,
      names: [...output.names, name],
      content: [...output.content, {
        index,
        name,
        component,
        hash: '',
        ...(options && {
          options
        })
      }]
    };
  }, initialStack);
}
//# sourceMappingURL=createModalStack.js.map