"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _hoistNonReactStatics = _interopRequireDefault(require("hoist-non-react-statics"));

var _ModalContext = _interopRequireDefault(require("./ModalContext"));

var _utils = require("../utils");

var _ModalState = require("./ModalState");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * HOC that provides the `modal` prop to a wrapped Class component.
 *
 * Note: Prefer `useModal()` Hook if you're using a Hook component.
 *
 * @param { React.ComponentClass<any> } Component - Component class.
 *
 * @returns Provided component class enhanced with the `modal` prop.
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/withmodal
 */
const withModal = Component => {
  var _class, _temp;

  const displayName = Component.displayName || Component.name;
  const {
    closeModal,
    closeModals,
    closeAllModals
  } = (0, _ModalState.modalfy)();
  const withModalComponent = (_temp = _class = class WithModalComponent extends _react.default.Component {
    render() {
      return /*#__PURE__*/_react.default.createElement(_ModalContext.default.Consumer, null, context => {
        (0, _utils.invariant)(context, `You should not use ${displayName} outside a <ModalProvider>`);
        return /*#__PURE__*/_react.default.createElement(Component, _extends({}, this.props, {
          modal: {
            closeModal,
            closeModals,
            closeAllModals,
            openModal: context.openModal,
            currentModal: context.currentModal
          }
        }));
      });
    }

  }, _defineProperty(_class, "WrappedComponent", Component), _defineProperty(_class, "displayName", `withModal(${displayName})`), _temp);
  return (0, _hoistNonReactStatics.default)(withModalComponent, Component);
};

var _default = withModal;
exports.default = _default;
//# sourceMappingURL=withModal.js.map