function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { useCallback } from 'use-memo-one';
import { BackHandler, Platform } from 'react-native';
import React, { useEffect, useRef, useState } from 'react';
import ModalStack from './ModalStack';
import ModalState from './ModalState';
import ModalContext from './ModalContext';
import { invariant, validateListener } from '../utils';

/**
 * `<ModalProvider>` is the component you're going to use to wrap your whole application,
 * so it'll be able to display your modals on top of everything else, using React Context API.
 *
 * @prop { ModalStackType } `stack` - Modal stack object generated by `createModalStack()`
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/guides/stack#provider
 */
const ModalProvider = _ref => {
  let {
    children,
    stack
  } = _ref;
  const modalStateSubscription = useRef();
  const modalEventListeners = useRef(new Set()).current;

  const openModal = (modalName, params, callback) => {
    const {
      currentModal
    } = ModalState.getState();

    if (!currentModal) {
      BackHandler.addEventListener('hardwareBackPress', ModalState.handleBackPress);
    }

    ModalState.openModal({
      modalName,
      params,
      callback,
      isCalledOutsideOfContext: true
    });
  };

  const getParam = (hash, paramName, defaultValue) => ModalState.getParam(hash, paramName, defaultValue);

  const closeModal = stackItem => ModalState.closeModal(stackItem);

  const closeModals = modalName => ModalState.closeModals(modalName);

  const closeAllModals = () => ModalState.closeAllModals();

  const [contextValue, setContextValue] = useState({
    stack,
    getParam,
    openModal,
    closeModal,
    closeModals,
    closeAllModals,
    currentModal: null
  });
  const registerListener = useCallback((hash, eventName, handler) => {
    validateListener('add', {
      eventName,
      handler
    });
    const newListener = {
      event: `${hash}_${eventName}`,
      handler
    };
    modalEventListeners.add(newListener);
    return {
      remove: () => modalEventListeners.delete(newListener)
    };
  }, [modalEventListeners]);
  const clearListeners = useCallback(hash => {
    modalEventListeners.forEach(item => {
      if (item.event.includes(hash)) modalEventListeners.delete(item);
    });
  }, [modalEventListeners]);

  const listener = (modalState, error) => {
    if (modalState) {
      setContextValue({ ...contextValue,
        currentModal: modalState.currentModal,
        stack: modalState.stack
      });
    } else console.warn('Modalfy', error);
  };

  useEffect(() => {
    invariant(stack, 'You need to provide a `stack` prop to <ModalProvider>');
    ModalState.init(() => ({
      currentModal: null,
      stack
    }));
    modalStateSubscription.current = ModalState.subscribe(listener);
    return () => {
      var _modalStateSubscripti;

      BackHandler.removeEventListener('hardwareBackPress', ModalState.handleBackPress);
      (_modalStateSubscripti = modalStateSubscription.current) === null || _modalStateSubscripti === void 0 ? void 0 : _modalStateSubscripti.unsubscribe();
    };
  }, []);
  useEffect(() => {
    // NOTE: Used to prevent scrolling on Web when the modal stack is opened.
    if (Platform.OS === 'web' && contextValue.stack.openedItems.size) {
      document.body.style.overflow = 'hidden';
      document.body.style.touchAction = 'none';
      document.body.style.overscrollBehavior = 'none';
    }

    return () => {
      if (Platform.OS === 'web') {
        document.body.style.overflow = 'auto';
        document.body.style.touchAction = 'auto';
        document.body.style.overscrollBehavior = 'auto';
      }
    };
  }, [contextValue.stack.openedItems.size]);
  return /*#__PURE__*/React.createElement(ModalContext.Provider, {
    value: contextValue
  }, /*#__PURE__*/React.createElement(React.Fragment, null, children, /*#__PURE__*/React.createElement(ModalStack, _extends({}, contextValue, {
    clearListeners: clearListeners,
    registerListener: registerListener,
    eventListeners: modalEventListeners,
    removeClosingAction: ModalState.removeClosingAction
  }))));
};

export default ModalProvider;
//# sourceMappingURL=ModalProvider.js.map