function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import hoistStatics from 'hoist-non-react-statics';
import ModalContext from './ModalContext';
import { invariant } from '../utils';
import { modalfy } from './ModalState';
/**
 * HOC that provides the `modal` prop to a wrapped Class component.
 *
 * Note: Prefer `useModal()` Hook if you're using a Hook component.
 *
 * @param { React.ComponentClass<any> } Component - Component class.
 *
 * @returns Provided component class enhanced with the `modal` prop.
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/withmodal
 */

const withModal = Component => {
  var _class, _temp;

  const displayName = Component.displayName || Component.name;
  const {
    closeModal,
    closeModals,
    closeAllModals
  } = modalfy();
  const withModalComponent = (_temp = _class = class WithModalComponent extends React.Component {
    render() {
      return /*#__PURE__*/React.createElement(ModalContext.Consumer, null, context => {
        invariant(context, `You should not use ${displayName} outside a <ModalProvider>`);
        return /*#__PURE__*/React.createElement(Component, _extends({}, this.props, {
          modal: {
            closeModal,
            closeModals,
            closeAllModals,
            openModal: context.openModal,
            currentModal: context.currentModal
          }
        }));
      });
    }

  }, _defineProperty(_class, "WrappedComponent", Component), _defineProperty(_class, "displayName", `withModal(${displayName})`), _temp);
  return hoistStatics(withModalComponent, Component);
};

export default withModal;
//# sourceMappingURL=withModal.js.map