export var __esModule: boolean;
export default _default;
/**
 * Function that exposes Modalfy's API outside of React's context.
 *
 * Note: Do not use if you're inside a React component.
 * Please consider `useModal()` or `withModal()` instead.
 *
 * @returns Object containing all the functions and variables of the usual `modal` prop.
 *
 * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/modalfy
 */
export function modalfy(): {
    /**
     * This function closes every open modal.
     *
     * @example modalfy().closeAllModals(() => console.log('All modals closed'))
     *
     * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/types/modalprop#closeallmodals
     */
    closeAllModals: (callback: any) => void;
    /**
     * This function closes the currently displayed modal by default.
     *
     * You can also provide a `modalName` if you want to close a different modal
     * than the latest opened. This will only close the latest instance of that modal,
     * see `closeModals()` if you want to close all instances.
     *
     * @example modalfy().closeModal('ExampleModal', () => console.log('Current modal closed'))
     *
     * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/types/modalprop#closemodal
     */
    closeModal: (modalName: any, callback: any) => void;
    /**
     * This function closes all the instances of a given modal.
     *
     * You can use it whenever you have the same modal opened
     * several times, to close all of them at once.
     *
     * @example modalfy().closeModals('ExampleModal', () => console.log('All ExampleModal modals closed'))
     *
     * @returns { boolean } Whether or not Modalfy found any open modal
     * corresponding to `modalName` (and then closed them).
     *
     * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/types/modalprop#closemodals
     */
    closeModals: (modalName: any, callback: any) => boolean;
    /**
     * This value returns the current open modal (`null` if none).
     *
     * @example modalfy().currentModal
     *
     * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/types/modalprop#currentmodal
     */
    currentModal: null;
    /**
     * This function opens a modal based on the provided `modalName`.
     *
     * It will look at the stack passed to `<ModalProvider>` and add
     * the corresponding component to the current stack of open modals.
     * Alternatively, you can also provide some `params` that will be
     * accessible to that component.
     *
     * @example modalfy().openModal('PokédexEntryModal', { id: 619, name: 'Lin-Fu' }, () => console.log('PokédexEntryModal modal opened'))
     *
     * @see https://colorfy-software.gitbook.io/react-native-modalfy/api/types/modalprop#openmodal
     */
    openModal: (modalName: any, params: any, callback: any) => void;
};
declare namespace _default {
    export { init };
    export { setState };
    export { getState };
    export { getParam };
    export { openModal };
    export { subscribe };
    export { closeModal };
    export { closeModals };
    export { closeAllModals };
    export { handleBackPress };
    export { queueClosingAction };
    export { removeClosingAction };
}
declare function init(updater: any): {
    currentModal: null;
    stack: {
        names: never[];
        content: never[];
        defaultOptions: {
            animateInConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            animateOutConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            containerStyle: {};
            position: string;
            backBehavior: string;
            backdropOpacity: number;
            disableFlingGesture: boolean;
            pointerEventsBehavior: string;
            backdropAnimationDuration: number;
        };
        openedItems: Set<any>;
        pendingClosingActions: Set<any>;
    };
};
declare function setState(updater: any): {
    currentModal: null;
    stack: {
        names: never[];
        content: never[];
        defaultOptions: {
            animateInConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            animateOutConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            containerStyle: {};
            position: string;
            backBehavior: string;
            backdropOpacity: number;
            disableFlingGesture: boolean;
            pointerEventsBehavior: string;
            backdropAnimationDuration: number;
        };
        openedItems: Set<any>;
        pendingClosingActions: Set<any>;
    };
};
declare function getState(): {
    currentModal: null;
    stack: {
        names: never[];
        content: never[];
        defaultOptions: {
            animateInConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            animateOutConfig: {
                duration: number;
                easing: _reactNative.EasingFunction;
            };
            containerStyle: {};
            position: string;
            backBehavior: string;
            backdropOpacity: number;
            disableFlingGesture: boolean;
            pointerEventsBehavior: string;
            backdropAnimationDuration: number;
        };
        openedItems: Set<any>;
        pendingClosingActions: Set<any>;
    };
};
declare function getParam(hash: any, paramName: any, defaultValue: any): any;
declare function openModal(_ref: any): void;
declare function subscribe(stateListener: any, ...args: any[]): {
    unsubscribe: () => boolean;
};
declare function closeModal(closingElement: any): void;
declare function closeModals(modalName: any): boolean;
declare function closeAllModals(): void;
declare function handleBackPress(): boolean;
declare function queueClosingAction(_ref2: any): any;
declare function removeClosingAction(action: any): boolean;
import _reactNative = require("react-native");
